/** \file
 * Provide a very lightweight Package class that represent a package, with
 * optional version, with very cheap value copy operations.
 */

/* 
 * Copyright (C) 2007  Enrico Zini <enrico@enricozini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */

#include <pkg/package.h>
#include <pkg/store.h>

namespace pkg
{

static Store store;

Package::Package() : impl(store.get("")) {}
Package::Package(const std::string& name) : impl(store.get(name)) {}
Package::Package(const std::string& name, const std::string& version) : impl(store.get(name, version)) {}
Package::~Package() { store.release(impl); }
std::string Package::name() const { return impl->name; }
std::string Package::version() const { return impl->version; }
bool Package::isValid() const { return impl->name != std::string(); }
bool Package::hasVersion() const { return impl->version != std::string(); }
bool Package::operator==(const Package& pkg) const
{
	return name() == pkg.name() && version() == pkg.version();
}
bool Package::operator!=(const Package& pkg) const
{
	return name() != pkg.name() || version() != pkg.version();
}
bool Package::operator<=(const Package& pkg) const
{
	if (name() < pkg.name())
		return true;
	if (name() == pkg.name())
		return version() <= pkg.version();
	return false;
}
bool Package::operator<(const Package& pkg) const
{
	if (name() < pkg.name())
		return true;
	if (name() == pkg.name())
		return version() < pkg.version();
	return false;
}
bool Package::operator>=(const Package& pkg) const
{
	if (name() > pkg.name())
		return true;
	if (name() == pkg.name())
		return version() >= pkg.version();
	return false;
}
bool Package::operator>(const Package& pkg) const
{
	if (name() > pkg.name())
		return true;
	if (name() == pkg.name())
		return version() > pkg.version();
	return false;
}

}

// vim:set ts=4 sw=4:
